# Accessibility, Inclusiveness, and Diversity at Events Handbook

## Overview
Lead and execute on making events a safe, welcome, navigable and inclusive space to new and continuing contributors. Lead and execute on outreach to underrepresented communities to invite them to participate. Track participant happiness and event inclusiveness over time to make each event more successful.

## Skills and Qualifications

Recommended experience: 
- Participated in a Kubecon Contributor Summit before
- Member of the Kubernetes org 
- Demonstrated awareness of existing research into accessibility, inclusiveness, and diversity, and willingness to apply research backed methods for improving the Contributor Summit along these axis
- Demonstrated commitment to ensuring Kubecon's Contributor Summit is accessible, inclusive, diverse, safe, and pleasant for all attendees
- Well organized, responsive via email, slack
- Available to participate in weekly planning sessions 
- Able to attend Contributor Summit 
- Comfortable reaching out to community groups to encourage their members to attend and participate 

## Activities  

- Work with Leads cross-functionally to ensure accessibility, inclusiveness, and diversity are core to the event  
- Use previous surveys, events, focus groups, and anything else needed to determine the success of previous events and how to improve for the next one 
- Review the previous workplan and use feedback and data to improve it for the upcoming event 
- Create a work plan for the upcoming event, review it with the events team for feedback and consensus  
- Execute the workplan, working cross-functionally with other leads and the CNCF Events team

### Work Plan Items 

- Pre-event: 
  * Reach out to under-represented group organizations to encourage and invite people to attend both the new Contributor workshops and the Contributor Summit, as appropriate. Remember a personal invitation, making yourself available, and encouragement can go a long way, versus simply blasting a message out to an email distribution and calling it a day
    - GoBridge: https://github.com/gobridge/about-us
    - Women Who Go: https://www.womenwhogo.org/ 
    - IEEE Women in Engineering: http://sites.ieee.org/scv-wie/introduction-to-kubernetes/ 
    - Women in Infrastructure: https://www.meetup.com/Women-in-Infrastructure/ 
    - Black girls code https://medium.com/@blackgirls_code 
    - Ada Academy https://www.adadevelopersacademy.org/
    - Women who code: https://www.womenwhocode.com/ 
    - Code Chix: https://www.codechix.org/ 
    - Girl Develop it: https://www.girldevelopit.com/ 
    - Mothercoders: http://www.mothercoders.org/ 
    - We can code it: https://wecancodeit.org/
    - Start Out: https://startout.org/
    - Out in Tech: https://outintech.com/
    - https://lgbtq.technology/
    - Queer Coders: https://queercoders.com/ 
    - Refugee Coders: https://powercoders.org/about/ 
  * Review previously collected anonymous gender and other demographic information to assess the environment, as perceived by different groups in your audience. Specifically ask how comfortable and welcome attendees felt at your conference and work to improve these marks (incorporating ideas they share) at future events
  * Ensure the Code of Conduct is linked from all official communications including the website, and that event staff is familiar with it and how to react in case of someone who needs assistance
- Speakers and presenters should: 
  * Take the CNCF Diversity training for speakers 
  * Review the Critical Listening Guide https://www.ncwit.org/resources/critical-listening-guide 
  * SIG updates should include a plan for how each SIG will be reaching out to and mentoring underrepresented people to increase inclusion in the projects 
  * There should be no panels or groups of >3 speakers that are entirely overrepresented people
- Summit location check list: 
  * The website and physical conference site is welcoming to people with disabilities
  * Make sure there is a microphone for all speakers
  * Avoid putting panelists on a stool or on a high platform stage
  * Ensure your check-in table allows attendees in wheelchairs to be greeted at eye-level
  * Provide at least one all-gender restroom, conveniently located close to the main session area, with appropriate signage
  * Provide preferred pronoun indication stickers 
  * Every session should include options for people who are vision and/or hearing impaired, etc
  * When people register, leave a box for requested special accommodations
  * There should be a clearly marked, private nursing room, that includes: 
    - ability to lock door from the inside 
    - clear signage 
    - easy to find and access without missing a lot of the summit due to transit time 
    - a comfortable chair 
    - working refrigerator 
    - power strip near chair 
    - completely private, no clear glass windows etc 
    - washing sink or wipes 
    - trash can 
    - paper towels
  * Childcare: 
    - Include a questionaire at registration to understand how many attendees need child care
    - Ask how old the children are so the appropriate type of childcare professionals are hired (babies may need pac and plays, for example - older kids need activities/playgrounds)
    - Ask parents to let you know if they decide to make alternate arrangements for childcare 
    - Offering events (workshops and social) at different times of day and in differing types of venues can go a long way to ensuring parents are able to attend, as does the availability and cost of on-site childcare. (For example, late evening events probably preclude parents from attending - an earlier social event at a child friendly venue might work better) 
 - Post-event: 
    * Collect anonymous gender and other demographic information to assess the environment, as perceived by different groups in your audience. Specifically ask how comfortable and welcome attendees felt at your conference and work to improve these marks (incorporating ideas they share) at future events
    * Review any issues that arose and enhance Code of Conduct if necessary 

## Time Commitment

About 1-2 hours a week leading up to the event, and then up to 20 hours the week of the event
Ideally, you need to be able to travel to the event (this can be worked around if necessary) 


## More reading / Citations 
- https://www.ncwit.org/resources/ncwit-tips-13-tips-make-technical-conferences-more-inclusive/ncwit-tips-13-tips-make 
- https://transequality.org/issues/resources/understanding-non-binary-people-how-to-be-respectful-and-supportive
